# pyTokenBucket

[![pypi version](https://img.shields.io/pypi/v/pytokenbucket.svg)](https://pypi.python.org/pypi/pytokenbucket)
[![Travis Status](https://img.shields.io/travis/cmeister2/pytokenbucket.svg)](https://travis-ci.org/cmeister2/pytokenbucket)
[![Documentation Status](https://readthedocs.org/projects/pytokenbucket/badge/?version=latest)](https://pytokenbucket.readthedocs.io/en/latest/?badge=latest)

A token bucket implementation for Python which only uses the standard
library.

  - Free software: MIT license
  - Documentation: <https://pytokenbucket.readthedocs.io>.

## Features
- Threaded token bucket which refreshes tokens at a given rate.

## Credits

This package was created with [Cookiecutter](https://github.com/audreyr/cookiecutter) and the [cmeister2/cookiecutter-pypackage](https://github.com/cmeister2/cookiecutter-pypackage) project template.
